==> ejc-procurement-impl-3.0.0-20251209.030124-86-sources.jar: com/ejianc/business/procurement/plan/service/impl/UnTenderMatterBpmServiceImpl.java <==
package com.ejianc.business.procurement.plan.service.impl;

import com.ejianc.business.procurement.plan.bean.InvitedTenderMatterEntity;
import com.ejianc.business.procurement.plan.bean.UnTenderMatterEntity;
import com.ejianc.business.procurement.plan.service.IInvitedTenderMatterService;
import com.ejianc.business.procurement.plan.service.IUnTenderMatterService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.QuoteParamsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("unTenderMatter") 
public class UnTenderMatterBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IUnTenderMatterService service;
	@Autowired
	private IInvitedTenderMatterService invitedTenderMatterService;
	@Autowired
	private IBillTypeApi billTypeApi;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批后回调
	 *
	 * @param billId	//单据id
	 * @param state		//单据状态
	 * @param billTypeCode		//单据类型code
	 * @param taskId		//该流程id
	 * @param isEnd		//该节点是否结束
	 * @return
	 */
	@Override
	public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String,Object> other){
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		UnTenderMatterEntity entity = service.selectById(billId);
		invitedTenderMatterService.UPDPurchasePlan(entity.getPlanId(),entity.getId(),entity.getBillCode(),Boolean.TRUE);
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		UnTenderMatterEntity entity = service.selectById(billId);
		//校验采购计划下游是否被引用
		QuoteParamsVO quoteParamsVO = new QuoteParamsVO();
		quoteParamsVO.setBillIds(Arrays.asList(entity.getPlanId()));
		quoteParamsVO.setBillTypeCode("BT202512000005");
		CommonResponse<List<Long>> resp = billTypeApi.checkQuotesAndReturnQuoteBillIds(quoteParamsVO);
		if(!resp.isSuccess()){
			return CommonResponse.error("查询引用校验失败！");
		} else {
			List<Long> resultIds = new ArrayList<>();
			List<Long> quoteIds = resp.getData();
			resultIds.addAll(quoteIds);
			resultIds.remove(billId);
			if (resultIds.size()>0){
				return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
			}
		}
		invitedTenderMatterService.UPDPurchasePlan(entity.getPlanId(),entity.getId(),entity.getBillCode(),Boolean.FALSE);
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-procurement-impl-3.0.0-20251212.100607-110-sources.jar: com/ejianc/business/procurement/plan/service/impl/UnTenderMatterBpmServiceImpl.java <==
package com.ejianc.business.procurement.plan.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.procurement.plan.bean.*;
import com.ejianc.business.procurement.plan.service.*;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.QuoteParamsVO;
import com.ejianc.framework.core.exception.BusinessException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("unTenderMatter") 
public class UnTenderMatterBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IUnTenderMatterService service;
	@Autowired
	private IInvitedTenderMatterService invitedTenderMatterService;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IAuthapplyDetailService authapplyDetailService;
	@Autowired
	private IPlanAllicateDetailService planAllicateDetailService;
	@Autowired
	private IPurchasePlanService planService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批后回调
	 *
	 * @param billId	//单据id
	 * @param state		//单据状态
	 * @param billTypeCode		//单据类型code
	 * @param taskId		//该流程id
	 * @param isEnd		//该节点是否结束
	 * @return
	 */
	@Override
	public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String,Object> other){
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		UnTenderMatterEntity entity = service.selectById(billId);
		invitedTenderMatterService.UPDPurchasePlan(entity.getPlanId(),entity.getId(),entity.getBillCode(),Boolean.TRUE);
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		UnTenderMatterEntity entity = service.selectById(billId);
		//校验采购计划下游是否被引用
		// 1，授权申请/委托
		//2，授权分配
		//3，采购计划 为正常状态
		int count =0;
		LambdaQueryWrapper<AuthapplyDetailEntity> lambdaQueryWrapper = Wrappers.lambdaQuery();
		lambdaQueryWrapper.eq(AuthapplyDetailEntity::getSourceBillId,entity.getPlanId())
				.eq(AuthapplyDetailEntity::getDr, 0);
		count = count+authapplyDetailService.count(lambdaQueryWrapper);
		LambdaQueryWrapper<PlanAllicateDetailEntity> lambdaQueryWrapper1 = Wrappers.lambdaQuery();
		lambdaQueryWrapper1.eq(PlanAllicateDetailEntity::getPlanId,entity.getPlanId())
				.eq(PlanAllicateDetailEntity::getDr, 0);
		count = count+planAllicateDetailService.count(lambdaQueryWrapper1);
		LambdaQueryWrapper<PurchasePlanEntity> lambdaQueryWrapper2 = Wrappers.lambdaQuery();
		lambdaQueryWrapper2.eq(PurchasePlanEntity::getId,entity.getPlanId())
				.eq(PurchasePlanEntity::getDr, 0)
				.eq(PurchasePlanEntity::getAbnormalStatus, 1);
		count = count+planService.count(lambdaQueryWrapper2);
		if (count>0){
			throw new BusinessException("该采购计划已存在业务单据");
		}
		invitedTenderMatterService.UPDPurchasePlan(entity.getPlanId(),entity.getId(),entity.getBillCode(),Boolean.FALSE);
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
